Fragment

Struct Fragment 

pub struct Fragment(/* private fields */);
IRI fragment.

Implementations

Source

impl Fragment

pub const fn validate_str(input: &str) -> bool

pub const fn validate_bytes(input: &[u8]) -> bool

Source

impl Fragment

pub fn new<T: ?Sized + AsRef<[u8]>>( input: &T, ) -> Result<&Self, InvalidFragment<&T>>

Creates a new fragment by parsing the input value.

pub const fn from_bytes(input: &[u8]) -> Result<&Self, InvalidFragment<&[u8]>>

Creates a new fragment by parsing the input bytes.

pub const fn from_str(input: &str) -> Result<&Self, InvalidFragment<&str>>

Creates a new fragment by parsing the input string.

pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self

Creates a new fragment from the input bytes without validation.

Safety

The input bytes must be a valid fragment.

pub const unsafe fn new_unchecked(input: &str) -> &Self

Creates a new fragment from the input string without validation.

Safety

The input string must be a valid fragment.

Source

impl Fragment

pub const fn as_str(&self) -> &str

Returns the fragment as a string.

pub const fn as_bytes(&self) -> &[u8]

Returns the fragment as a byte string.

Source

impl Fragment

pub const EMPTY: &'static Self

The empty fragment.

pub fn as_pct_str(&self) -> &PctStr

Returns the fragment as a percent-encoded string slice.

Methods from Deref<Target = PctStr>

pub fn len(&self) -> usize

Length of the decoded string (character count).

Computed in linear time. This is different from the byte length, which can be retrieved using value.as_bytes().len().

pub fn is_empty(&self) -> bool

Checks if the string is empty.

pub fn as_bytes(&self) -> &[u8]

Returns the underlying percent-encoding bytes.

pub fn as_str(&self) -> &str

Get the underlying percent-encoded string slice.

pub fn chars(&self) -> Chars<'_>

Iterate over the encoded characters of the string.

pub fn bytes(&self) -> Bytes<'_>

Iterate over the encoded bytes of the string.

pub fn decode(&self) -> String

Decoding.

Return the string with the percent-encoded characters decoded.