Segment

Struct Segment 

pub struct Segment(/* private fields */);
IRI path segment.

Implementations

Source

impl Segment

pub const fn validate_str(input: &str) -> bool

pub const fn validate_bytes(input: &[u8]) -> bool

Source

impl Segment

pub fn new<T: ?Sized + AsRef<[u8]>>( input: &T, ) -> Result<&Self, InvalidSegment<&T>>

Creates a new segment by parsing the input value.

pub const fn from_bytes(input: &[u8]) -> Result<&Self, InvalidSegment<&[u8]>>

Creates a new segment by parsing the input bytes.

pub const fn from_str(input: &str) -> Result<&Self, InvalidSegment<&str>>

Creates a new segment by parsing the input string.

pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self

Creates a new segment from the input bytes without validation.

Safety

The input bytes must be a valid segment.

pub const unsafe fn new_unchecked(input: &str) -> &Self

Creates a new segment from the input string without validation.

Safety

The input string must be a valid segment.

Source

impl Segment

pub const fn as_str(&self) -> &str

Returns the segment as a string.

pub const fn as_bytes(&self) -> &[u8]

Returns the segment as a byte string.

Source

impl Segment

pub const EMPTY: &Self

Empty segment.

pub const CURRENT: &Self

Current directory (.) segment.

pub const PARENT: &Self

Parent directory (..) segment.

pub fn as_pct_str(&self) -> &PctStr

Returns the segment as a percent-encoded string slice.

pub fn len(&self) -> usize

Segment byte length.

pub fn is_empty(&self) -> bool

Whether or not the segment is empty.

pub fn looks_like_scheme(&self) -> bool

Checks if this segment looks like a scheme.

Returns true if it is of the form prefix:suffix where prefix is a valid scheme, of false otherwise.

Methods from Deref<Target = PctStr>

pub fn len(&self) -> usize

Length of the decoded string (character count).

Computed in linear time. This is different from the byte length, which can be retrieved using value.as_bytes().len().

pub fn is_empty(&self) -> bool

Checks if the string is empty.

pub fn as_bytes(&self) -> &[u8]

Returns the underlying percent-encoding bytes.

pub fn as_str(&self) -> &str

Get the underlying percent-encoded string slice.

pub fn chars(&self) -> Chars<'_>

Iterate over the encoded characters of the string.

pub fn bytes(&self) -> Bytes<'_>

Iterate over the encoded bytes of the string.

pub fn decode(&self) -> String

Decoding.

Return the string with the percent-encoded characters decoded.