pub struct Segment(/* private fields */);Expand description
IRI path segment.
Implementations
Sourceimpl Segment
impl Segment
pub const fn validate_str(input: &str) -> bool
pub const fn validate_bytes(input: &[u8]) -> bool
Sourceimpl Segment
impl Segment
Sourcepub fn new<T: ?Sized + AsRef<[u8]>>(
input: &T,
) -> Result<&Self, InvalidSegment<&T>>
pub fn new<T: ?Sized + AsRef<[u8]>>( input: &T, ) -> Result<&Self, InvalidSegment<&T>>
Creates a new segment by parsing the input value.
Sourcepub const fn from_bytes(input: &[u8]) -> Result<&Self, InvalidSegment<&[u8]>>
pub const fn from_bytes(input: &[u8]) -> Result<&Self, InvalidSegment<&[u8]>>
Creates a new segment by parsing the input bytes.
Sourcepub const fn from_str(input: &str) -> Result<&Self, InvalidSegment<&str>>
pub const fn from_str(input: &str) -> Result<&Self, InvalidSegment<&str>>
Creates a new segment by parsing the input string.
Sourcepub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self
pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self
Creates a new segment from the input bytes without validation.
Safety
The input bytes must be a valid segment.
Sourcepub const unsafe fn new_unchecked(input: &str) -> &Self
pub const unsafe fn new_unchecked(input: &str) -> &Self
Creates a new segment from the input string without validation.
Safety
The input string must be a valid segment.
Sourceimpl Segment
impl Segment
Sourcepub fn as_pct_str(&self) -> &PctStr
pub fn as_pct_str(&self) -> &PctStr
Returns the segment as a percent-encoded string slice.
Sourcepub fn looks_like_scheme(&self) -> bool
pub fn looks_like_scheme(&self) -> bool
Checks if this segment looks like a scheme.
Returns true if it is of the form prefix:suffix where prefix is a
valid scheme, of false otherwise.
Methods from Deref<Target = PctStr>